==> open-xchange-util-custom_1.2.1.orig.tar.bz2: open-xchange-util-custom-1.2.1/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/ServiceDependencyQualifiers.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.util.activator.impl;

import static com.openexchange.util.custom.base.NullUtil.f;
import java.lang.annotation.Annotation;
import java.util.Set;
import org.osgi.framework.ServiceReference;
import com.google.common.collect.ImmutableSet;
import com.openexchange.util.activator.Service;

public enum ServiceDependencyQualifiers implements ServiceDependencyQualifier {
    NO_ID_QUALIFIER {

        @Override
        public String contributeFilter() {
            return null;
        }

        @Override
        public String contributeIdentification() {
            return "no-id";
        }

        @Override
        public Set<String> contributePropertiesOfInterest() {
            return ID_PROPERTY;
        }

        @Override
        public boolean matchesService(Object serviceInstance, ServiceReference<?> reference) {
            return reference.getProperty("id") == null;
        }

        @Override
        public boolean matchesDependency(Class<?> serviceClass, Annotation[] annotations) {
            return true;
        }
        
    },
    
    ANY_ID_QUALIFIER {

        @Override
        public String contributeFilter() {
            return null;
        }

        @Override
        public String contributeIdentification() {
            return "id=*";
        }

        @Override
        public Set<String> contributePropertiesOfInterest() {
            return ImmutableSet.of();
        }

        @Override
        public boolean matchesService(Object serviceInstance, ServiceReference<?> reference) {
            return true;
        }

        @Override
        public boolean matchesDependency(Class<?> serviceClass, Annotation[] annotations) {
            return true;
        }
        
    }
    ;
    
    private static final ImmutableSet<String> ID_PROPERTY = ImmutableSet.of("id");
    
    
    private static class IdQualifier implements ServiceDependencyQualifier {
        
        private final String id;
        
        public IdQualifier(String id) {
            this.id = id;
        }

        @Override
        public String contributeFilter() {
            return f("(id=%s)", id);
        }

        @Override
        public String contributeIdentification() {
            return f("id=%s", id);
        }

        @Override
        public Set<String> contributePropertiesOfInterest() {
            return ID_PROPERTY;
        }

        @Override
        public boolean matchesService(Object serviceInstance, ServiceReference<?> reference) {
            return this.id.equals(reference.getProperty("id"));
        }

        @Override
        public boolean matchesDependency(Class<?> serviceClass, Annotation[] annotations) {
            final Service serviceAnnotation = RegistrationTools.serviceAnnotation(annotations);
            return serviceAnnotation != null && serviceAnnotation.id() != null
                && serviceAnnotation.id().equals(this.id);
        }
        
    }
    
    public static final IdQualifier mustMatchId(final String id) {
        return new IdQualifier(id);
    }
}

==> open-xchange-util-custom_1.3.2.orig.tar.bz2: open-xchange-util-custom-1.3.2/com.openexchange.util.custom/src/com/openexchange/util/activator/impl/ServiceDependencyQualifiers.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.util.activator.impl;

import static com.openexchange.util.custom.base.NullUtil.f;
import static com.openexchange.util.custom.base.NullUtil.immutableSet;
import java.lang.annotation.Annotation;
import java.util.Set;
import org.osgi.framework.ServiceReference;
import com.google.common.collect.ImmutableSet;
import com.openexchange.annotation.Nullable;
import com.openexchange.util.activator.Service;

public enum ServiceDependencyQualifiers implements ServiceDependencyQualifier {
    NO_ID_QUALIFIER {

        @Override
        public @Nullable String contributeFilter() {
            return "(!(id=*))";
        }

        @Override
        public @Nullable String contributeIdentification() {
            return "no-id";
        }

        @Override
        public @Nullable Set<String> contributePropertiesOfInterest() {
            return ID_PROPERTY;
        }

        @Override
        public boolean matchesService(Object serviceInstance, ServiceReference<?> reference) {
            return reference.getProperty("id") == null;
        }

        @Override
        public boolean matchesDependency(Class<?> serviceClass, @Nullable Annotation[] annotations) {
            return true;
        }
        
    },
    
    ANY_ID_QUALIFIER {

        @Override
        public @Nullable String contributeFilter() {
            return null;
        }

        @Override
        public @Nullable String contributeIdentification() {
            return "id=*";
        }

        @Override
        public @Nullable Set<String> contributePropertiesOfInterest() {
            return ImmutableSet.of();
        }

        @Override
        public boolean matchesService(Object serviceInstance, ServiceReference<?> reference) {
            return true;
        }

        @Override
        public boolean matchesDependency(Class<?> serviceClass, @Nullable Annotation[] annotations) {
            return true;
        }
        
    }
    ;
    
    private static final ImmutableSet<String> ID_PROPERTY = immutableSet("id");
    
    private static class IdQualifier implements ServiceDependencyQualifier {
        
        private final String id;
        
        public IdQualifier(String id) {
            this.id = id;
        }

        @Override
        public @Nullable String contributeFilter() {
            return f("(id=%s)", id);
        }

        @Override
        public @Nullable String contributeIdentification() {
            return f("id=%s", id);
        }

        @Override
        public @Nullable Set<String> contributePropertiesOfInterest() {
            return ID_PROPERTY;
        }

        @Override
        public boolean matchesService(Object serviceInstance, ServiceReference<?> reference) {
            return this.id.equals(reference.getProperty("id"));
        }

        @Override
        public boolean matchesDependency(Class<?> serviceClass, @Nullable Annotation[] annotations) {
            final @Nullable Service serviceAnnotation = RegistrationTools.serviceAnnotation(annotations);
            return serviceAnnotation != null && serviceAnnotation.id().equals(this.id);
        }
        
    }
    
    public static final IdQualifier mustMatchId(final String id) {
        return new IdQualifier(id);
    }
}
